==> django_szuprefix_saas-0.3.13-py2-none-any.whl: django_szuprefix_saas/exam/stats.py <==
# -*- coding:utf-8 -*- 
# author = 'denishuang'
from __future__ import unicode_literals
from . import models
from django_szuprefix.utils import statutils


def count_answer_user(qset=None, measures=None, period=None):
    if qset is None:
        qset = models.Answer.objects.all()
    qset = statutils.using_stats_db(qset)
    dstat = statutils.DateStat(qset, 'create_time')
    funcs = {
        'today': lambda: dstat.stat("今天", count_field="user_id", distinct=True, only_first=True),
        'yesterday': lambda: dstat.stat("昨天", count_field="user_id", distinct=True, only_first=True),
        'all': lambda: qset.values("user_id").distinct().count(),
        'daily': lambda: dstat.stat(period, count_field='user_id', distinct=True),
        'clazz': lambda: statutils.count_by(
            dstat.get_period_query_set(period),
            'user__as_school_student__clazz__name',
            count_field='user_id',
            distinct=True, sort="-"),
        'course': lambda: statutils.count_by(
            dstat.get_period_query_set(period).filter(paper__course_courses__isnull=False),
            "paper__course_courses__name",
            count_field='user_id',
            distinct=True, sort="-"),
        'chapter': lambda: statutils.count_by(
            dstat.get_period_query_set(period).filter(paper__course_chapters__isnull=False),
            "paper__course_chapters__name",
            count_field='user_id',
            distinct=True, sort="-")
    }
    return dict([(m, funcs[m]()) for m in measures])

==> django_szuprefix_saas-0.4.7-py2-none-any.whl: django_szuprefix_saas/exam/stats.py <==
# -*- coding:utf-8 -*- 
# author = 'denishuang'
from __future__ import unicode_literals
from . import models
from django_szuprefix.utils import statutils

def detail_group_stat(qset, measure):
    r = {}
    for a in qset:
        statutils.group_stat(a.detail, ['number', measure], r, list_action='seperate')
    return r


def sort_by(a):
    if a['stat']['right']:
        return a['stat']['right'].get(True, 0) / (1 + a['stat']['right'].get(False))


def stats_answer(qset=None, measures=None, period=None):
    qset = qset if qset is not None else models.Answer.objects.all()
    qset = statutils.using_stats_db(qset)
    dstat = statutils.DateStat(qset, 'create_time')
    funcs = {
        'today': lambda: dstat.stat("今天", count_field="user_id", distinct=True, only_first=True),
        'yesterday': lambda: dstat.stat("昨天", count_field="user_id", distinct=True, only_first=True),
        'all': lambda: qset.values("user_id").distinct().count(),
        'count': lambda: dstat.get_period_query_set(period).count(),
        'daily': lambda: dstat.stat(period, count_field='user_id', distinct=True),
        'clazz': lambda: statutils.count_by(
            dstat.get_period_query_set(period),
            'user__as_school_student__clazz__name',
            count_field='user_id',
            distinct=True, sort="-"),
        'course': lambda: statutils.count_by(
            dstat.get_period_query_set(period).filter(paper__course_courses__isnull=False),
            "paper__course_courses__name",
            count_field='user_id',
            distinct=True, sort="-"),
        'chapter': lambda: statutils.count_by(
            dstat.get_period_query_set(period).filter(paper__course_chapters__isnull=False),
            "paper__course_chapters__name",
            count_field='user_id',
            distinct=True, sort="-"),
        'right': lambda: detail_group_stat(dstat.get_period_query_set(period), 'right'),
        'userAnswer': lambda: detail_group_stat(dstat.get_period_query_set(period), 'userAnswer'),
    }
    return dict([(m, funcs[m]()) for m in measures])
